@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -305,7 +305,9 @@ qjackctlClientItem::qjackctlClientItem ( qjackctlClientList *pClientList )
 // Default destructor.
 qjackctlClientItem::~qjackctlClientItem (void)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	qDeleteAll(m_ports);
+#endif
 	m_ports.clear();
 
 	const int iClient = m_pClientList->clients().indexOf(this);
@@ -452,7 +454,7 @@ int qjackctlClientItem::cleanClientPorts ( int iMark )
 		if (pPort->portMark() == iMark) {
 			iter.remove();
 			delete pPort;
-			iDirtyCount++;
+			++iDirtyCount;
 		}
 	}
 	
@@ -536,7 +538,9 @@ qjackctlClientList::~qjackctlClientList (void)
 // Do proper contents cleanup.
 void qjackctlClientList::clear (void)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	qDeleteAll(m_clients);
+#endif
 	m_clients.clear();
 
 	if (m_pListView)
@@ -563,7 +567,7 @@ qjackctlPortItem *qjackctlClientList::findClientPort (
 	const QString& sClientPort )
 {
 	qjackctlPortItem *pPort = 0;
-	int iColon = sClientPort.indexOf(':');
+	const int iColon = sClientPort.indexOf(':');
 	if (iColon >= 0) {
 		qjackctlClientItem *pClient = findClient(sClientPort.left(iColon));
 		if (pClient) {
@@ -616,7 +620,7 @@ int qjackctlClientList::cleanClientPorts ( int iMark )
 		if (pClient->clientMark() == iMark) {
 			iter.remove();
 			delete pClient;
-			iDirtyCount++;
+			++iDirtyCount;
 		} else {
 			iDirtyCount += pClient->cleanClientPorts(iMark);
 		}
@@ -1005,7 +1009,11 @@ void qjackctlClientListView::dragEnterEvent ( QDragEnterEvent *pDragEnterEvent )
 {
 	if (pDragEnterEvent->source() != this &&
 		pDragEnterEvent->mimeData()->hasText() &&
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		dragDropItem(pDragEnterEvent->position().toPoint())) {
+	#else
 		dragDropItem(pDragEnterEvent->pos())) {
+	#endif
 		pDragEnterEvent->accept();
 	} else {
 		pDragEnterEvent->ignore();
@@ -1017,7 +1025,11 @@ void qjackctlClientListView::dragMoveEvent ( QDragMoveEvent *pDragMoveEvent )
 {
 	if (pDragMoveEvent->source() != this &&
 		pDragMoveEvent->mimeData()->hasText() &&
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		dragDropItem(pDragMoveEvent->position().toPoint())) {
+	#else
 		dragDropItem(pDragMoveEvent->pos())) {
+	#endif
 		pDragMoveEvent->accept();
 	} else {
 		pDragMoveEvent->ignore();
@@ -1037,7 +1049,11 @@ void qjackctlClientListView::dropEvent( QDropEvent *pDropEvent )
 {
 	if (pDropEvent->source() != this &&
 		pDropEvent->mimeData()->hasText() &&
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		dragDropItem(pDropEvent->position().toPoint())) {
+	#else
 		dragDropItem(pDropEvent->pos())) {
+	#endif
 		const QString sText = pDropEvent->mimeData()->text();
 		qjackctlConnect *pConnect = m_pConnectView->binding();
 		if (!sText.isEmpty() && pConnect)
@@ -1986,11 +2002,11 @@ void qjackctlConnect::updateContents ( bool bClear )
 		// Add (newer) client:ports and respective connections...
 		if (m_pOClientList->updateClientPorts() > 0) {
 			m_pOClientList->refresh();
-			iDirtyCount++;
+			++iDirtyCount;
 		}
 		if (m_pIClientList->updateClientPorts() > 0) {
 			m_pIClientList->refresh();
-			iDirtyCount++;
+			++iDirtyCount;
 		}			
 		updateConnections();
 		endMutex();
