@@ -1,7 +1,7 @@
 // qjackctlGraph.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@
 
 #include <algorithm>
 
-#include <math.h>
+#include <cmath>
 
 
 //----------------------------------------------------------------------------
@@ -108,6 +108,9 @@ void qjackctlGraphItem::setHighlight ( bool hilite )
 {
 	m_hilite = hilite;
 
+	if (m_hilite)
+		raise();
+
 	QGraphicsPathItem::update();
 }
 
@@ -118,6 +121,30 @@ bool qjackctlGraphItem::isHighlight (void) const
 }
 
 
+// Raise item z-value (dynamic always-on-top).
+void qjackctlGraphItem::raise (void)
+{
+	static qreal s_zvalue = 0.0;
+
+	switch (type()) {
+	case  qjackctlGraphPort::Type: {
+		QGraphicsPathItem::setZValue(s_zvalue += 0.003);
+		qjackctlGraphPort *port = static_cast<qjackctlGraphPort *> (this);
+		if (port) {
+			qjackctlGraphNode *node = port->portNode();
+			if (node)
+				node->setZValue(s_zvalue += 0.002);
+		}
+		break;
+	}
+	case qjackctlGraphConnect::Type:
+	default:
+		QGraphicsPathItem::setZValue(s_zvalue += 0.001);
+		break;
+	}
+}
+
+
 // Item-type hash (static)
 uint qjackctlGraphItem::itemType ( const QByteArray& type_name )
 {
@@ -142,7 +169,7 @@ qjackctlGraphPort::qjackctlGraphPort ( qjackctlGraphNode *node,
 		m_name(name), m_mode(mode), m_type(type), m_index(0),
 		m_selectx(0), m_hilitex(0)
 {
-	QGraphicsPathItem::setZValue(+1);
+	QGraphicsPathItem::setZValue(+1.0);
 
 	const QPalette pal;
 	setForeground(pal.buttonText().color());
@@ -292,9 +319,9 @@ void qjackctlGraphPort::removeConnects (void)
 {
 	foreach (qjackctlGraphConnect *connect, m_connects) {
 		if (connect->port1() != this)
-			connect->setPort1(0);
+			connect->setPort1(nullptr);
 		if (connect->port2() != this)
-			connect->setPort2(0);
+			connect->setPort2(nullptr);
 	}
 
 	// Do not delete connects here as they are owned elsewhere...
@@ -315,6 +342,13 @@ qjackctlGraphConnect *qjackctlGraphPort::findConnect ( qjackctlGraphPort *port )
 }
 
 
+// Connect-list accessor.
+const QList<qjackctlGraphConnect *>& qjackctlGraphPort::connects (void) const
+{
+	return m_connects;
+}
+
+
 void qjackctlGraphPort::paint ( QPainter *painter,
 	const QStyleOptionGraphicsItem *option, QWidget */*widget*/ )
 {
@@ -560,7 +594,7 @@ qjackctlGraphNode::qjackctlGraphNode (
 	: qjackctlGraphItem(nullptr),
 		m_name(name), m_mode(mode), m_type(type)
 {
-	QGraphicsPathItem::setZValue(0);
+	QGraphicsPathItem::setZValue(0.0);
 
 	const QPalette pal;
 	const int base_value = pal.base().color().value();
@@ -597,6 +631,8 @@ qjackctlGraphNode::qjackctlGraphNode (
 	effect->setBlurRadius(is_darkest ? 8 : 16);
 	effect->setOffset(is_darkest ? 0 : 2);
 	QGraphicsPathItem::setGraphicsEffect(effect);
+
+	qjackctlGraphItem::raise();
 }
 
 
@@ -739,6 +775,13 @@ qjackctlGraphPort *qjackctlGraphNode::findPort (
 }
 
 
+// Port-list accessor.
+const QList<qjackctlGraphPort *>& qjackctlGraphNode::ports (void) const
+{
+	return m_ports;
+}
+
+
 // Reset port markings, destroy if unmarked.
 void qjackctlGraphNode::resetMarkedPorts (void)
 {
@@ -878,7 +921,7 @@ QRectF qjackctlGraphNode::editorRect (void) const
 qjackctlGraphConnect::qjackctlGraphConnect (void)
 	: qjackctlGraphItem(nullptr), m_port1(nullptr), m_port2(nullptr)
 {
-	QGraphicsPathItem::setZValue(-1);
+	QGraphicsPathItem::setZValue(-1.0);
 
 	QGraphicsPathItem::setFlag(QGraphicsItem::ItemIsSelectable);
 
@@ -896,6 +939,8 @@ qjackctlGraphConnect::qjackctlGraphConnect (void)
 	QGraphicsPathItem::setGraphicsEffect(effect);
 
 	QGraphicsPathItem::setAcceptHoverEvents(true);
+
+	qjackctlGraphItem::raise();
 }
 
 
@@ -964,13 +1009,17 @@ void qjackctlGraphConnect::updatePathTo ( const QPointF& pos )
 	const QPointF pos1 = (is_out0 ? pos0 : pos);
 	const QPointF pos4 = (is_out0 ? pos : pos0);
 
+	const qreal d2 = (is_out0 ? +2.0 : -2.0);
+	const QPointF pos1_2(pos1.x() + d2, pos1.y());
+	const QPointF pos3_4(pos4.x() - d2, pos4.y());
+
 	qjackctlGraphNode *node1 = m_port1->portNode();
 	const QRectF& rect1 = node1->boundingRect();
-	const qreal dx = pos4.x() - pos1.x();
+	const qreal dx = pos3_4.x() - pos1_2.x();
 	const qreal dy = pos0.y() - node1->scenePos().y() - 0.5 * rect1.height();
 	const qreal y_max = rect1.height() + rect1.width();
 	const qreal y_min = qMin(y_max, qAbs(dx));
-	const qreal x_offset = (dx > 0.0 ? 0.5 : 1.0) * y_min;
+	const qreal x_offset = (dx > 0.0 ? 0.5 : 1.5) * y_min;
 	const qreal y_offset = (dx > 0.0 ? 0.0 : (dy > 0.0 ? +y_min : -y_min));
 
 	const QPointF pos2(pos1.x() + x_offset, pos1.y() + y_offset);
@@ -978,10 +1027,14 @@ void qjackctlGraphConnect::updatePathTo ( const QPointF& pos )
 
 	QPainterPath path;
 	path.moveTo(pos1);
-	path.cubicTo(pos2, pos3, pos4);
+	path.lineTo(pos1_2);
+	path.cubicTo(pos2, pos3, pos3_4);
+	path.lineTo(pos4);
 	const qreal arrow_angle = path.angleAtPercent(0.5) * M_PI / 180.0;
 	const QPointF arrow_pos0 = path.pointAtPercent(0.5);
-	path.cubicTo(pos3, pos2, pos1);
+	path.lineTo(pos3_4);
+	path.cubicTo(pos3, pos2, pos1_2);
+	path.lineTo(pos1);
 	const qreal arrow_size = 12.0;
 	QVector<QPointF> arrow;
 	arrow.append(arrow_pos0);
@@ -1101,7 +1154,7 @@ static const char *CanvasZoomKey = "/CanvasZoom";
 
 static const char *NodePosGroup  = "/GraphNodePos";
 
-static const char *ColorsGroup      = "/GraphColors";
+static const char *ColorsGroup   = "/GraphColors";
 
 
 // Constructor.
@@ -1271,8 +1324,18 @@ bool qjackctlGraphCanvas::canConnect (void) const
 bool qjackctlGraphCanvas::canDisconnect (void) const
 {
 	foreach (QGraphicsItem *item, m_scene->selectedItems()) {
-		if (item->type() == qjackctlGraphConnect::Type)
+		switch (item->type()) {
+		case qjackctlGraphConnect::Type:
 			return true;
+		case qjackctlGraphPort::Type: {
+			qjackctlGraphPort *port = static_cast<qjackctlGraphPort *> (item);
+			if (!port->connects().isEmpty())
+				return true;
+			// Fall-thru...;
+		}
+		default:
+			break;
+		}
 	}
 
 	return false;
@@ -1296,8 +1359,8 @@ void qjackctlGraphCanvas::setZoom ( qreal zoom )
 	if (zoom < 0.1)
 		zoom = 0.1;
 	else
-	if (zoom > 2.0)
-		zoom = 2.0;
+	if (zoom > 1.9)
+		zoom = 1.9;
 
 	const qreal scale = zoom / m_zoom;
 	QGraphicsView::scale(scale, scale);
@@ -1481,6 +1544,7 @@ void qjackctlGraphCanvas::mouseMoveEvent ( QMouseEvent *event )
 						m_connect = new qjackctlGraphConnect();
 						m_connect->setPort1(port);
 						m_connect->setSelected(true);
+						m_connect->raise();
 						m_scene->addItem(m_connect);
 						m_item = nullptr;
 						++m_selected_nodes;
@@ -1583,6 +1647,8 @@ void qjackctlGraphCanvas::mouseMoveEvent ( QMouseEvent *event )
 		else
 		if (m_connect) {
 			// Hovering ports high-lighting...
+			const qreal zval = m_connect->zValue();
+			m_connect->setZValue(-1.0);
 			QGraphicsItem *item = itemAt(pos);
 			if (item && item->type() == qjackctlGraphPort::Type) {
 				qjackctlGraphPort *port1 = m_connect->port1();
@@ -1593,6 +1659,7 @@ void qjackctlGraphCanvas::mouseMoveEvent ( QMouseEvent *event )
 					port2->update();
 				}
 			}
+			 m_connect->setZValue(zval);
 		}
 		break;
 	case DragScroll:
@@ -1633,6 +1700,7 @@ void qjackctlGraphCanvas::mouseReleaseEvent ( QMouseEvent *event )
 	case DragMove:
 		// Close new connection line...
 		if (m_connect) {
+			 m_connect->setZValue(-1.0);
 			const QPointF& pos
 				= QGraphicsView::mapToScene(event->pos());
 			qjackctlGraphItem *item = itemAt(pos);
@@ -1661,10 +1729,9 @@ void qjackctlGraphCanvas::mouseReleaseEvent ( QMouseEvent *event )
 					++nchanged;
 				}
 			}
-			if (m_connect) {
-				delete m_connect;
-				m_connect = nullptr;
-			}
+			// Done with the hovering connection...
+			delete m_connect;
+			m_connect = nullptr;
 		}
 		// Maybe some node(s) were moved...
 		if (m_item && m_item->type() == qjackctlGraphNode::Type) {
@@ -1819,10 +1886,23 @@ void qjackctlGraphCanvas::disconnectItems (void)
 	QList<qjackctlGraphConnect *> connects;
 
 	foreach (QGraphicsItem *item, m_scene->selectedItems()) {
-		if (item->type() == qjackctlGraphConnect::Type) {
+		switch (item->type()) {
+		case qjackctlGraphConnect::Type: {
 			qjackctlGraphConnect *connect = static_cast<qjackctlGraphConnect *> (item);
-			if (connect)
+			if (!connects.contains(connect))
 				connects.append(connect);
+			break;
+		}
+		case qjackctlGraphPort::Type: {
+			qjackctlGraphPort *port = static_cast<qjackctlGraphPort *> (item);
+			foreach (qjackctlGraphConnect *connect, port->connects()) {
+				if (!connects.contains(connect))
+					connects.append(connect);
+			}
+			// Fall-thru...
+		}
+		default:
+			break;
 		}
 	}
 
