@@ -1,7 +1,7 @@
 // qjackctlGraph.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -83,6 +83,9 @@ public:
 	void setHighlight(bool hilite);
 	bool isHighlight() const;
 
+	// Raise item z-value (dynamic always-on-top).
+	void raise();
+
 	// Item modes.
 	enum Mode { None = 0,
 		Input = 1, Output = 2,
@@ -198,6 +201,9 @@ public:
 
 	qjackctlGraphConnect *findConnect(qjackctlGraphPort *port) const;
 
+	// Connect-list accessor.
+	const QList<qjackctlGraphConnect *>& connects() const;
+
 	// Selection propagation method...
 	void setSelectedEx(bool is_selected);
 
@@ -322,6 +328,9 @@ public:
 	// Port finder (by name, mode and type)
 	qjackctlGraphPort *findPort(const QString& name, Mode mode, uint type = 0);
 
+	// Port-list accessor.
+	const QList<qjackctlGraphPort *>& ports() const;
+
 	// Reset port markings, destroy if unmarked.
 	void resetMarkedPorts();
 
