@@ -1,7 +1,7 @@
 // qjackctlJackConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -34,8 +34,8 @@ static QString prettyName (	jack_uuid_t uuid )
 {
 	QString sPrettyName;
 
-	char *pszValue = NULL;
-	char *pszType  = NULL;
+	char *pszValue = nullptr;
+	char *pszType  = nullptr;
 
 	if (::jack_get_property(uuid,
 			JACK_METADATA_PRETTY_NAME, &pszValue, &pszType) == 0) {
@@ -53,10 +53,10 @@ static QString prettyName (	jack_uuid_t uuid )
 static void setPrettyName (
 	jack_client_t *pJackClient, jack_uuid_t uuid, const QString& sPrettyName )
 {
-	const char *pszValue = sPrettyName.toUtf8().constData();
+	const QByteArray aPrettyName = sPrettyName.toUtf8();
 
 	::jack_set_property(pJackClient, uuid,
-		JACK_METADATA_PRETTY_NAME, pszValue, NULL);
+		JACK_METADATA_PRETTY_NAME, aPrettyName.constData(), nullptr);
 }
 
 static void removePrettyName (
@@ -74,17 +74,14 @@ static void removePrettyName (
 
 // Constructor.
 qjackctlJackPort::qjackctlJackPort (
-	qjackctlJackClient *pClient, jack_port_t *pJackPort )
+	qjackctlJackClient *pClient, unsigned long ulPortFlags )
 	: qjackctlPortItem(pClient)
 {
-	m_pJackPort = pJackPort;
-
 	qjackctlJackConnect *pJackConnect
 		= static_cast<qjackctlJackConnect *> (
 			((pClient->clientList())->listView())->binding());
 
 	if (pJackConnect) {
-		const unsigned long ulPortFlags = jack_port_flags(m_pJackPort);
 		if (ulPortFlags & JackPortIsInput) {
 			if (ulPortFlags & JackPortIsTerminal) {
 				QTreeWidgetItem::setIcon(0, QIcon(pJackConnect->pixmap(
@@ -115,18 +112,11 @@ qjackctlJackPort::~qjackctlJackPort (void)
 }
 
 
-// Jack port handles accessors.
-jack_port_t *qjackctlJackPort::jackPort (void) const
-{
-	return m_pJackPort;
-}
-
-
 // Pretty/display name method (virtual override).
 void qjackctlJackPort::updatePortName ( bool bRename )
 {
 #ifdef CONFIG_JACK_METADATA
-	jack_client_t *pJackClient = NULL;
+	jack_client_t *pJackClient = nullptr;
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
 		pJackClient = pMainForm->jackClient();
@@ -134,24 +124,30 @@ void qjackctlJackPort::updatePortName ( bool bRename )
 		bool bRenameEnabled = false;
 		QString sPortNameEx = portNameAlias(&bRenameEnabled);
 		const QString& sPortName = portName();
-		jack_uuid_t port_uuid = ::jack_port_uuid(m_pJackPort);
-		const QString& sPrettyName = prettyName(port_uuid);
-		if (sPortNameEx != sPortName && sPortNameEx != sPrettyName) {
-			if (sPrettyName.isEmpty() || bRename) {
-				setPrettyName(pJackClient, port_uuid, sPortNameEx);
-			} else {
-				sPortNameEx = sPrettyName;
-				setPortNameAlias(sPortNameEx);
+		const QString& sClientPort = clientName() + ':' + sPortName;
+		const QByteArray aClientPort = sClientPort.toUtf8();
+		const char *pszClientPort = aClientPort.constData();
+		jack_port_t *pJackPort = jack_port_by_name(pJackClient, pszClientPort);
+		if (pJackPort) {
+			jack_uuid_t port_uuid = ::jack_port_uuid(pJackPort);
+			const QString& sPrettyName = prettyName(port_uuid);
+			if (sPortNameEx != sPortName && sPortNameEx != sPrettyName) {
+				if (sPrettyName.isEmpty() || bRename) {
+					setPrettyName(pJackClient, port_uuid, sPortNameEx);
+				} else {
+					sPortNameEx = sPrettyName;
+					setPortNameAlias(sPortNameEx);
+				}
 			}
+			else
+			if (sPortNameEx == sPortName
+				&& !sPrettyName.isEmpty() && bRename) {
+				removePrettyName(pJackClient, port_uuid);
+			}
+			setPortText(sPortNameEx, bRenameEnabled);
+			return;
 		}
-		else
-		if (sPortNameEx == sPortName
-			&& !sPrettyName.isEmpty() && bRename) {
-			removePrettyName(pJackClient, port_uuid);
-		}
-		setPortText(sPortNameEx, bRenameEnabled);
 	}
-	else
 #endif
 	qjackctlPortItem::updatePortName(bRename);
 }
@@ -160,17 +156,30 @@ void qjackctlJackPort::updatePortName ( bool bRename )
 // Tooltip text builder (virtual override).
 QString qjackctlJackPort::tooltip (void) const
 {
-	jack_latency_range_t latency_range;
 
-	jack_port_get_latency_range(m_pJackPort,
-		client()->isReadable() ? JackCaptureLatency : JackPlaybackLatency,
-		&latency_range);
+	jack_client_t *pJackClient = nullptr;
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pJackClient = pMainForm->jackClient();
+	if (pJackClient) {
+		const QString& sPortName = portName();
+		const QString& sClientPort = clientName() + ':' + sPortName;
+		const QByteArray aClientPort = sClientPort.toUtf8();
+		const char *pszClientPort = aClientPort.constData();
+		jack_port_t *pJackPort = jack_port_by_name(pJackClient, pszClientPort);
+		if (pJackPort) {
+			jack_latency_range_t latency_range;
+			jack_port_get_latency_range(pJackPort,
+				client()->isReadable() ? JackCaptureLatency : JackPlaybackLatency,
+				&latency_range);
+			QString sLatency = QString::number(latency_range.min);
+			if (latency_range.max > latency_range.min)
+				sLatency +=  '-' + QString::number(latency_range.max);
+			return QObject::tr("%1 (%2 frames)").arg(portName()).arg(sLatency);
+		}
+	}
 
-	QString sLatency = QString::number(latency_range.min);
-	if (latency_range.max > latency_range.min)
-		sLatency +=  '-' + QString::number(latency_range.max);
-
-	return QObject::tr("%1 (%2 frames)").arg(portName()).arg(sLatency);
+	return portName();
 }
 
 
@@ -205,17 +214,17 @@ qjackctlJackClient::~qjackctlJackClient (void)
 
 
 // Jack port lookup.
-qjackctlJackPort *qjackctlJackClient::findJackPort ( jack_port_t *pJackPort )
+qjackctlJackPort *qjackctlJackClient::findJackPort ( const QString& sPortName )
 {
 	QListIterator<qjackctlPortItem *> iter(ports());
 	while (iter.hasNext()) {
 		qjackctlJackPort *pPort
 			= static_cast<qjackctlJackPort *> (iter.next());
-		if (pPort && pPort->jackPort() == pJackPort)
+		if (pPort && pPort->portName() == sPortName)
 			return pPort;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -223,7 +232,7 @@ qjackctlJackPort *qjackctlJackClient::findJackPort ( jack_port_t *pJackPort )
 void qjackctlJackClient::updateClientName ( bool bRename )
 {
 #ifdef CONFIG_JACK_METADATA
-	jack_client_t *pJackClient = NULL;
+	jack_client_t *pJackClient = nullptr;
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
 		pJackClient = pMainForm->jackClient();
@@ -231,10 +240,9 @@ void qjackctlJackClient::updateClientName ( bool bRename )
 		bool bRenameEnabled = false;
 		QString sClientNameEx = clientNameAlias(&bRenameEnabled);
 		const QString& sClientName = clientName();
-		const char *pszClientName
-			= sClientName.toUtf8().constData();
+		const QByteArray aClientName = sClientName.toUtf8();
 		const char *pszClientUuid
-			= ::jack_get_uuid_for_client_name(pJackClient, pszClientName);
+			= ::jack_get_uuid_for_client_name(pJackClient, aClientName.constData());
 		if (pszClientUuid) {
 			jack_uuid_t client_uuid = 0;
 			::jack_uuid_parse(pszClientUuid, &client_uuid);
@@ -280,20 +288,30 @@ qjackctlJackClientList::~qjackctlJackClientList (void)
 
 
 // Jack port lookup.
-qjackctlJackPort *qjackctlJackClientList::findJackClientPort ( jack_port_t *pJackPort )
+qjackctlJackPort *qjackctlJackClientList::findJackClientPort (
+	const QString& sClientPort )
 {
+	const int iColon = sClientPort.indexOf(':');
+	if (iColon < 0)
+		return nullptr;
+
+	const QString& sClientName
+		= sClientPort.left(iColon);
+	const QString& sPortName
+		= sClientPort.right(sClientPort.length() - iColon - 1);
+
 	QListIterator<qjackctlClientItem *> iter(clients());
 	while (iter.hasNext()) {
 		qjackctlJackClient *pClient
 			= static_cast<qjackctlJackClient *> (iter.next());
-		if (pClient) {
-			qjackctlJackPort *pPort = pClient->findJackPort(pJackPort);
+		if (pClient && pClient->clientName() == sClientName) {
+			qjackctlJackPort *pPort = pClient->findJackPort(sPortName);
 			if (pPort)
 				return pPort;
 		}
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -301,16 +319,16 @@ qjackctlJackPort *qjackctlJackClientList::findJackClientPort ( jack_port_t *pJac
 int qjackctlJackClientList::updateClientPorts (void)
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return 0;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return 0;
 
 	qjackctlJackConnect *pJackConnect
 		= static_cast<qjackctlJackConnect *> (listView()->binding());
-	if (pJackConnect == NULL)
+	if (pJackConnect == nullptr)
 		return 0;
 
 	const char *pszJackType = JACK_DEFAULT_AUDIO_TYPE;
@@ -333,11 +351,10 @@ int qjackctlJackClientList::updateClientPorts (void)
 	const char **ppszClientPorts = jack_get_ports(pJackClient, 0,
 		pszJackType, isReadable() ? JackPortIsOutput : JackPortIsInput);
 	if (ppszClientPorts) {
-		int iClientPort = 0;
-		while (ppszClientPorts[iClientPort]) {
+		for (int iClientPort = 0; ppszClientPorts[iClientPort]; ++iClientPort) {
 			QString sClientPort = QString::fromUtf8(ppszClientPorts[iClientPort]);
-			qjackctlJackClient *pClient = 0;
-			qjackctlJackPort   *pPort   = 0;
+			qjackctlJackClient *pClient = nullptr;
+			qjackctlJackPort *pPort = nullptr;
 			jack_port_t *pJackPort = jack_port_by_name(pJackClient,
 				ppszClientPorts[iClientPort]);
 		#ifdef CONFIG_JACK_PORT_ALIASES
@@ -345,10 +362,10 @@ int qjackctlJackClientList::updateClientPorts (void)
 				jack_port_get_aliases(pJackPort, aliases) >= g_iJackClientPortAlias)
 				sClientPort = QString::fromUtf8(aliases[g_iJackClientPortAlias - 1]);
 		#endif
-			int iColon = sClientPort.indexOf(':');
+			const int iColon = sClientPort.indexOf(':');
 			if (pJackPort && iColon >= 0) {
 				QString sClientName = sClientPort.left(iColon);
-				QString sPortName   = sClientPort.right(sClientPort.length() - iColon - 1);
+				QString sPortName = sClientPort.right(sClientPort.length() - iColon - 1);
 				pClient = static_cast<qjackctlJackClient *> (findClient(sClientName));
 				if (pClient)
 					pPort = static_cast<qjackctlJackPort *> (pClient->findPort(sPortName));
@@ -358,14 +375,13 @@ int qjackctlJackClientList::updateClientPorts (void)
 					iDirtyCount++;
 				}
 				if (pClient && pPort == 0) {
-					pPort = new qjackctlJackPort(pClient, pJackPort);
+					pPort = new qjackctlJackPort(pClient, jack_port_flags(pJackPort));
 					pPort->setPortName(sPortName);
 					iDirtyCount++;
 				}
 				if (pPort)
 					pPort->markClientPort(1);
 			}
-			iClientPort++;
 		}
 		::free(ppszClientPorts);
 	}
@@ -485,7 +501,7 @@ void qjackctlJackConnect::deleteIconPixmaps (void)
 	for (int i = 0; i < QJACKCTL_JACK_PIXMAPS; i++) {
 		if (m_apPixmaps[i])
 			delete m_apPixmaps[i];
-		m_apPixmaps[i] = NULL;
+		m_apPixmaps[i] = nullptr;
 	}
 }
 
@@ -501,11 +517,11 @@ const QPixmap& qjackctlJackConnect::pixmap ( int iPixmap ) const
 bool qjackctlJackConnect::connectPorts ( qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return false;
 
 	qjackctlJackPort *pOJack = static_cast<qjackctlJackPort *> (pOPort);
@@ -521,11 +537,11 @@ bool qjackctlJackConnect::connectPorts ( qjackctlPortItem *pOPort, qjackctlPortI
 bool qjackctlJackConnect::disconnectPorts ( qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return false;
 
 	qjackctlJackPort *pOJack = static_cast<qjackctlJackPort *> (pOPort);
@@ -541,16 +557,16 @@ bool qjackctlJackConnect::disconnectPorts ( qjackctlPortItem *pOPort, qjackctlPo
 void qjackctlJackConnect::updateConnections (void)
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return;
 
 	qjackctlJackClientList *pIClientList
 		= static_cast<qjackctlJackClientList *> (IClientList());
-	if (pIClientList == NULL)
+	if (pIClientList == nullptr)
 		return;
 
 	// For each output client item...
@@ -568,26 +584,29 @@ void qjackctlJackConnect::updateConnections (void)
 			qjackctlJackPort *pOJack
 				= static_cast<qjackctlJackPort *> (pOPort);
 			// Get port connections...
-			const char **ppszClientPorts
-				= jack_port_get_all_connections(
-					pJackClient, pOJack->jackPort());
-			if (ppszClientPorts) {
-				// Now, for each input client port...
-				int iClientPort = 0;
-				while (ppszClientPorts[iClientPort]) {
-					jack_port_t *pJackPort = jack_port_by_name(
-						pJackClient, ppszClientPorts[iClientPort]);
-					if (pJackPort) {
+			const QString& sClientPort
+				= pOJack->clientName() + ':' + pOJack->portName();
+			const QByteArray aClientPort = sClientPort.toUtf8();
+			const char *pszClientPort = aClientPort.constData();
+			jack_port_t *pJackPort
+				= jack_port_by_name(pJackClient, pszClientPort);
+			if (pJackPort) {
+				const char **ppszClientPorts
+					= jack_port_get_all_connections(pJackClient, pJackPort);
+				if (ppszClientPorts) {
+					// Now, for each input client port...
+					for (int iClientPort = 0;
+							ppszClientPorts[iClientPort]; ++iClientPort) {
 						qjackctlPortItem *pIPort
-							= pIClientList->findJackClientPort(pJackPort);
+							= pIClientList->findJackClientPort(
+								ppszClientPorts[iClientPort]);
 						if (pIPort) {
 							pOPort->addConnect(pIPort);
 							pIPort->addConnect(pOPort);
 						}
 					}
-					iClientPort++;
+					::free(ppszClientPorts);
 				}
-				::free(ppszClientPorts);
 			}
 		}
 	}
